@@ -8,7 +8,8 @@ package Lemonldap::NG::Portal::_i18n;
 # Developpers warning : this file must stay UTF-8 encoded
 
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.2.3';
+our $VERSION = '1.4.0';
+use utf8;
 
 ## @fn string msg(int msg, array ref lang)
 # @param $msg Number of msg to resolve
@@ -33,7 +34,9 @@ sub error {
     $error = 0 if ( $error < 0 );
     foreach ( @{$lang} ) {
         if ( __PACKAGE__->can("error_$_") ) {
-            return &{"error_$_"}->[$error];
+            my $tmp = &{"error_$_"}->[$error];
+            utf8::encode($tmp) if ( $ENV{FCGI_ROLE} );
+            return $tmp;
         }
     }
     return &error_en->[$error];
@@ -119,6 +122,11 @@ __END__
 # * PE_RADIUSCONNECTFAILED		 73
 # * PE_MUST_SUPPLY_OLD_PASSWORD          74
 # * PE_FORBIDDENIP                       75
+# * PE_CAPTCHAERROR                      76
+# * PE_CAPTCHAEMPTY                      77
+# * PE_REGISTERFIRSTACCESS               78
+# * PE_REGISTERFORMEMPTY                 79
+# * PE_REGISTERALREADYEXISTS             80
 
 # Not used in errors:
 # * PE_DONE                -1
@@ -206,8 +214,11 @@ sub error_fr {
         'La connexion au serveur Radius a échoué',
         "L'ancien mot de passe est obligatoire",
         'Vous venez d\'une adresse IP qui n\'est pas accréditée',
-        'Mauvais code',
-        'Vous devez entrez le captcha'
+        'Erreur dans la saisie du captcha',
+        'Vous devez saisir le captcha',
+        'Merci de saisir vos informations',
+        'Une information est manquante',
+        'Cette adresse est déjà utilisée',
     ];
 }
 
@@ -292,8 +303,11 @@ sub error_en {
         'Radius connection has failed',
         'Old password is required',
         'You came from an unaccredited IP address',
-        'Wrong code',
-        'You have to tape the captcha'
+        'You failed at typing the captcha',
+        'You have to type the captcha',
+        'Please enter your information',
+        'An information is missing',
+        'This address is already used',
     ];
 }
 
@@ -379,8 +393,11 @@ sub error_ro {
         'Radius connection has failed',
         'Old password is required',
         'You came from an unaccredited IP address',
-        'Bad cod',
-        'trebuie să introduceţi CAPTCHA'
+        'You failed at typing the captcha',
+        'trebuie să introduceţi CAPTCHA',
+        'Please enter your information',
+        'An information is missing',
+        'This address is already used',
     ];
 }
 
